From e8a29cf134f7df1a1e7637083f6d7adf64949b7c Mon Sep 17 00:00:00 2001
From: jmontoya <jmontoya@ispconfig3>
Date: Wed, 04 Aug 2010 12:57:28 -0400
Subject: [PATCH] Adding new functions to the Remoting class

---
 interface/web/sites/shell_user_list.php |    7 ++-----
 1 files changed, 2 insertions(+), 5 deletions(-)

diff --git a/interface/web/sites/shell_user_list.php b/interface/web/sites/shell_user_list.php
index 3909b84..a9c95fd 100644
--- a/interface/web/sites/shell_user_list.php
+++ b/interface/web/sites/shell_user_list.php
@@ -41,11 +41,8 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 $app->uses('listform_actions');
 

--
Gitblit v1.9.1